@@ -1,10 +1,9 @@
 from functools import partial
-from typing import Tuple
 
 import jax
 import jax.numpy as jnp
 
-import pgx.core as core
+import pgx
 from pgx.flax.struct import dataclass
 
 TRUE = jnp.bool_(True)
@@ -14,13 +13,16 @@ init_dice_pattern: jnp.ndarray = jnp.array([[0, 1], [0, 2], [0, 3], [0, 4], [0,
 
 
 @dataclass
-class State(core.State):
-    curr_player: jnp.ndarray = jnp.int8(0)
+class State(pgx.State):
+    steps: jnp.ndarray = jnp.int32(0)
+    current_player: jnp.ndarray = jnp.int8(0)
     observation: jnp.ndarray = jnp.zeros(34, dtype=jnp.int8)
     reward: jnp.ndarray = jnp.float32([0.0, 0.0])
     terminated: jnp.ndarray = FALSE
+    truncated: jnp.ndarray = FALSE
     # micro action = 6 * src + die
     legal_action_mask: jnp.ndarray = jnp.zeros(6 * 26 + 6, dtype=jnp.bool_)
+    _rng_key: jax.random.KeyArray = jax.random.PRNGKey(0)
     # --- Backgammon specific ---
     # 各point(24) bar(2) off(2)にあるcheckerの数. 黒+, 白-
     board: jnp.ndarray = jnp.zeros(28, dtype=jnp.int8)
@@ -36,32 +38,42 @@ class State(core.State):
     turn: jnp.ndarray = jnp.int8(1)
 
 
-class Backgammon(core.Env):
+class Backgammon(pgx.Env):
+    def __init__(
+        self,
+        *,
+        auto_reset: bool = False,
+        max_truncation_steps: int = -1,
+    ):
+        super().__init__(
+            auto_reset=auto_reset, max_truncation_steps=max_truncation_steps
+        )
+
     def _init(self, key: jax.random.KeyArray) -> State:
         return init(key)
 
-    def _step(self, state: core.State, action: jnp.ndarray) -> State:
+    def _step(self, state: pgx.State, action: jnp.ndarray) -> State:
         assert isinstance(state, State)
         return step(state, action)
 
-    def observe(
-        self, state: core.State, player_id: jnp.ndarray
+    def _observe(
+        self, state: pgx.State, player_id: jnp.ndarray
     ) -> jnp.ndarray:
         assert isinstance(state, State)
         return observe(state, player_id)
 
     @property
-    def num_players(self) -> int:
-        return 2
+    def version(self) -> str:
+        return "beta"
 
     @property
-    def reward_range(self) -> Tuple[float, float]:
-        return 0.0, 3.0
+    def num_players(self) -> int:
+        return 2
 
 
 def init(rng: jax.random.KeyArray) -> State:
     rng1, rng2, rng3 = jax.random.split(rng, num=3)
-    curr_player: jnp.ndarray = jax.random.bernoulli(rng1).astype(jnp.int8)
+    current_player: jnp.ndarray = jax.random.bernoulli(rng1).astype(jnp.int8)
     board: jnp.ndarray = _make_init_board()  # 初期配置は対象なので, turnに関係
     terminated: jnp.ndarray = FALSE
     dice: jnp.ndarray = _roll_init_dice(rng2)
@@ -70,7 +82,7 @@ def init(rng: jax.random.KeyArray) -> State:
     turn: jnp.ndarray = _init_turn(dice)
     legal_action_mask: jnp.ndarray = _legal_action_mask(board, playable_dice)
     state = State(  # type: ignore
-        curr_player=curr_player,
+        current_player=current_player,
         rng=rng3,
         board=board,
         terminated=terminated,
@@ -102,7 +114,7 @@ def observe(state: State, player_id: jnp.ndarray) -> jnp.ndarray:
     board: jnp.ndarray = state.board
     zero_one_dice_vec: jnp.ndarray = _to_zero_one_dice_vec(state.playable_dice)
     return jax.lax.cond(
-        player_id == state.curr_player,
+        player_id == state.current_player,
         lambda: jnp.concatenate((board, zero_one_dice_vec), axis=None),  # type: ignore
         lambda: jnp.concatenate(
             (board, jnp.zeros(6, dtype=jnp.int8)), axis=None  # type: ignore
@@ -138,7 +150,7 @@ def _winning_step(
     勝利者がいる場合のstep.
     """
     win_score = _calc_win_score(state.board)
-    winner = state.curr_player
+    winner = state.current_player
     reward = jnp.ones_like(state.reward)
     reward = reward.at[winner].set(win_score)
     state = state.replace(terminated=TRUE)  # type: ignore
@@ -162,7 +174,7 @@ def _update_by_action(state: State, action: jnp.ndarray) -> State:
     """
     is_no_op = action // 6 == 0
     rng = state.rng
-    curr_player: jnp.ndarray = state.curr_player
+    current_player: jnp.ndarray = state.current_player
     terminated: jnp.ndarray = state.terminated
     board: jnp.ndarray = _move(state.board, action)
     played_dice_num: jnp.ndarray = jnp.int16(state.played_dice_num + 1)
@@ -174,7 +186,7 @@ def _update_by_action(state: State, action: jnp.ndarray) -> State:
         is_no_op,
         lambda: state,
         lambda: state.replace(  # type: ignore
-            curr_player=curr_player,
+            current_player=current_player,
             rng=rng,
             terminated=terminated,
             board=board,
@@ -220,14 +232,14 @@ def _change_turn(state: State) -> State:
     rng1, rng2 = jax.random.split(state.rng)
     board: jnp.ndarray = flip_board(state.board)  # boardを反転させて黒視点に変える
     turn: jnp.ndarray = (state.turn + 1) % 2  # turnを変える
-    curr_player: jnp.ndarray = (state.curr_player + 1) % 2
+    current_player: jnp.ndarray = (state.current_player + 1) % 2
     terminated: jnp.ndarray = state.terminated
     dice: jnp.ndarray = _roll_dice(rng1)  # diceを振る
     playable_dice: jnp.ndarray = _set_playable_dice(dice)  # play可能なサイコロを初期化
     played_dice_num: jnp.ndarray = jnp.int16(0)
     legal_action_mask: jnp.ndarray = _legal_action_mask(board, dice)
     return state.replace(  # type: ignore
-        curr_player=curr_player,
+        current_player=current_player,
         rng=rng2,
         board=board,
         terminated=terminated,
