@@ -1,6 +1,7 @@
+import jax
 import jax.numpy as jnp
 
-import pgx.core as core
+import pgx
 from pgx.flax.struct import dataclass
 
 FALSE = jnp.bool_(False)
@@ -8,12 +9,15 @@ TRUE = jnp.bool_(True)
 
 
 @dataclass
-class State(core.State):
-    curr_player: jnp.ndarray = jnp.int8(0)
+class State(pgx.State):
+    steps: jnp.ndarray = jnp.int32(0)
+    current_player: jnp.ndarray = jnp.int8(0)
     observation: jnp.ndarray = jnp.zeros(27, dtype=jnp.bool_)
     reward: jnp.ndarray = jnp.float32([0.0, 0.0])
     terminated: jnp.ndarray = FALSE
+    truncated: jnp.ndarray = FALSE
     legal_action_mask: jnp.ndarray = jnp.ones(9, dtype=jnp.bool_)
+    _rng_key: jax.random.KeyArray = jax.random.PRNGKey(0)
     # ---
     turn: jnp.ndarray = jnp.int8(0)
     # 8x8 board
