@@ -33,12 +33,11 @@ piece_board (81,):
 """
 
 from functools import partial
-from typing import Tuple
 
 import jax
 import jax.numpy as jnp
 
-import pgx.core as core
+import pgx
 from pgx.cache import (
     load_shogi_is_on_the_way,
     load_shogi_legal_from_mask,
@@ -116,12 +115,15 @@ QUEEN_MOVES = load_shogi_queen_moves()  # (81, 81)
 
 
 @dataclass
-class State(core.State):
-    curr_player: jnp.ndarray = jnp.int8(0)
+class State(pgx.State):
+    steps: jnp.ndarray = jnp.int32(0)
+    current_player: jnp.ndarray = jnp.int8(0)
     reward: jnp.ndarray = jnp.float32([0.0, 0.0])
     terminated: jnp.ndarray = FALSE
+    truncated: jnp.ndarray = FALSE
     legal_action_mask: jnp.ndarray = jnp.zeros(27 * 81, dtype=jnp.bool_)
     observation: jnp.ndarray = jnp.zeros((119, 9, 9), dtype=jnp.bool_)
+    _rng_key: jax.random.KeyArray = jax.random.PRNGKey(0)
     # --- Shogi specific ---
     turn: jnp.ndarray = jnp.int8(0)  # 0 or 1
     piece_board: jnp.ndarray = INIT_PIECE_BOARD  # (81,) 後手のときにはflipする
@@ -135,7 +137,7 @@ class State(core.State):
     @staticmethod
     def _from_board(turn, piece_board: jnp.ndarray, hand: jnp.ndarray):
         """Mainly for debugging purpose.
-        terminated, reward, and curr_player are not changed"""
+        terminated, reward, and current_player are not changed"""
         state = State(turn=turn, piece_board=piece_board, hand=hand)  # type: ignore
         # fmt: off
         state = state.replace(effects=state.effects.at[0].set(_effects_all(state)))  # type: ignore
@@ -147,37 +149,44 @@ class State(core.State):
         return state.replace(legal_action_mask=legal_action_mask, legal_moves=legal_moves)  # type: ignore
 
 
-class Shogi(core.Env):
-    def __init__(self):
-        super().__init__()
+class Shogi(pgx.Env):
+    def __init__(
+        self,
+        *,
+        auto_reset: bool = False,
+        max_truncation_steps: int = -1,
+    ):
+        super().__init__(
+            auto_reset=auto_reset, max_truncation_steps=max_truncation_steps
+        )
 
     def _init(self, key: jax.random.KeyArray) -> State:
         return init(key)
 
-    def _step(self, state: core.State, action: jnp.ndarray) -> State:
+    def _step(self, state: pgx.State, action: jnp.ndarray) -> State:
         assert isinstance(state, State)
         return step(state, action)
 
-    def observe(
-        self, state: core.State, player_id: jnp.ndarray
+    def _observe(
+        self, state: pgx.State, player_id: jnp.ndarray
     ) -> jnp.ndarray:
         assert isinstance(state, State)
         return observe(state, player_id)
 
     @property
-    def num_players(self) -> int:
-        return 2
+    def version(self) -> str:
+        return "beta"
 
     @property
-    def reward_range(self) -> Tuple[float, float]:
-        return -1.0, 1.0
+    def num_players(self) -> int:
+        return 2
 
 
 def init(rng):
     state = _init()
     rng, subkey = jax.random.split(rng)
-    curr_player = jnp.int8(jax.random.bernoulli(subkey))
-    return state.replace(curr_player=curr_player)
+    current_player = jnp.int8(jax.random.bernoulli(subkey))
+    return state.replace(current_player=current_player)
 
 
 def _init():
@@ -320,7 +329,7 @@ def step(state: State, action: jnp.ndarray) -> State:
 
 def observe(state: State, player_id: jnp.ndarray) -> jnp.ndarray:
     state = jax.lax.cond(
-        state.curr_player != player_id, lambda: _flip(state), lambda: state
+        state.current_player != player_id, lambda: _flip(state), lambda: state
     )
 
     def piece_and_effect(state):
@@ -396,7 +405,8 @@ def _step(state: State, action: Action) -> State:
     # flip state
     state = _flip(state)
     state = state.replace(  # type: ignore
-        curr_player=(state.curr_player + 1) % 2, turn=(state.turn + 1) % 2
+        current_player=(state.current_player + 1) % 2,
+        turn=(state.turn + 1) % 2,
     )
     legal_moves, legal_promotions, legal_drops = _legal_actions(state)
     legal_action_mask = _to_direction(
@@ -409,7 +419,7 @@ def _step(state: State, action: Action) -> State:
         lambda: jnp.float32([0.0, 0.0]),
     )
     reward = jax.lax.cond(
-        state.curr_player != 0, lambda: reward[::-1], lambda: reward
+        state.current_player != 0, lambda: reward[::-1], lambda: reward
     )
     return state.replace(  # type: ignore
         reward=reward,
