@@ -10,6 +10,7 @@ from .dwg.bridge_bidding import BridgeBiddingState, _make_bridge_dwg
 from .dwg.chess import ChessState, _make_chess_dwg
 from .dwg.connect_four import ConnectFourState, _make_connect_four_dwg
 from .dwg.go import GoState, _make_go_dwg
+from .dwg.hex import HexState, _make_hex_dwg
 from .dwg.othello import OthelloState, _make_othello_dwg
 from .dwg.shogi import ShogiState, _make_shogi_dwg
 from .dwg.sparrowmahjong import SparrowMahjongState, _make_sparrowmahjong_dwg
@@ -396,6 +397,34 @@ class Visualizer:
                     "black",
                     "",
                 )
+        elif isinstance(_state, HexState):
+            self.config["GRID_SIZE"] = 30
+            self.config["BOARD_WIDTH"] = int(_state.size * 1.3)
+            self.config["BOARD_HEIGHT"] = int(_state.size * 0.8)
+            self._make_dwg_group = _make_hex_dwg
+            if (
+                self.config["COLOR_MODE"] is None
+                and self.config["COLOR_MODE"] == "dark"
+            ) or self.config["COLOR_MODE"] == "dark":
+                self.config["COLOR_SET"] = ColorSet(
+                    "black",
+                    "white",
+                    "white",
+                    "black",
+                    "#1e1e1e",
+                    "white",
+                    "dimgray",
+                )
+            else:
+                self.config["COLOR_SET"] = ColorSet(
+                    "black",
+                    "white",
+                    "black",
+                    "black",
+                    "white",
+                    "black",
+                    "lightgray",
+                )
         elif isinstance(_state, OthelloState):
             self.config["GRID_SIZE"] = 30
             self.config["BOARD_WIDTH"] = 8
@@ -518,7 +547,7 @@ class Visualizer:
         elif isinstance(_states, BridgeBiddingState):
             return BridgeBiddingState(  # type:ignore
                 turn=_states.turn[_i],
-                curr_player=_states.curr_player[_i],
+                current_player=_states.current_player[_i],
                 hand=_states.hand[_i],
                 bidding_history=_states.bidding_history[_i],
                 vul_NS=_states.vul_NS[_i],
@@ -527,7 +556,7 @@ class Visualizer:
         elif isinstance(_states, GoState):
             return GoState(  # type:ignore
                 size=_states.size[_i],
-                ren_id_board=_states.ren_id_board[_i],
+                ren_id_board=_states.chain_id_board[_i],
                 turn=_states.turn[_i],
             )
         elif isinstance(_states, OthelloState):
@@ -542,7 +571,7 @@ class Visualizer:
             )
         elif isinstance(_states, SparrowMahjongState):
             return SparrowMahjongState(
-                curr_player=_states.curr_player[_i],
+                current_player=_states.current_player[_i],
                 turn=_states.turn[_i],
                 rivers=_states.rivers[_i],
                 hands=_states.hands[_i],
@@ -555,7 +584,7 @@ class Visualizer:
             )
         elif isinstance(_states, TictactoeState):
             return TictactoeState(
-                curr_player=_states.curr_player[_i],
+                current_player=_states.current_player[_i],
                 legal_action_mask=_states.legal_action_mask[_i],
                 terminated=_states.terminated[_i],
                 turn=_states.turn[_i],
