@@ -13,7 +13,7 @@ def test_jit():
         env = pgx.make(env_name)
 
         print(env.num_players)
-        print(env.reward_range)
+        print(env.illegal_action_penalty)
         print(env.observation_shape)
         print(env.action_shape)
 
@@ -23,13 +23,13 @@ def test_jit():
         keys = jax.random.split(key, N)
 
         state = init(keys)
-        assert state.curr_player.shape == (N,)
+        assert state.current_player.shape == (N,)
         assert (state.observation).sum() != 0
 
         action = act_randomly(key, state)
 
         state: pgx.State = step(state, action)
-        assert state.curr_player.shape == (N,)
+        assert state.current_player.shape == (N,)
         assert (state.observation).sum() != 0
 
 
